@@ -230,8 +230,8 @@ eog_application_init_accelerators (GtkApplication *application)
 					"<Ctrl>KP_Subtract", NULL,
 		"win.zoom-normal",	"<Ctrl>0", NULL,
 
-		"win.view-gallery",	"F9", NULL,
-		"win.view-sidebar",	"<Ctrl>F9", NULL,
+		"win.view-gallery",	"<Ctrl>F9", NULL,
+		"win.view-sidebar",	"F9", NULL,
 		"win.view-fullscreen",	"F11", NULL,
 		"win.view-slideshow",	"F5", NULL,
 		"win.toggle-zoom-fit",	"F", NULL,
